@@ -18,6 +18,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredE
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableWhy;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.OperationResult;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
 
@@ -31,7 +32,6 @@ import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
 import com.sencha.gxt.cell.core.client.form.ComboBoxCell.TriggerAction;
-import com.sencha.gxt.core.client.dom.ScrollSupport.ScrollMode;
 import com.sencha.gxt.core.client.util.Margins;
 import com.sencha.gxt.data.client.loader.RpcProxy;
 import com.sencha.gxt.data.shared.LabelProvider;
@@ -195,7 +195,7 @@ public class DenormalizePanel extends FramedPanel implements
 		hBox.add(denormalizeButton, new BoxLayoutData(new Margins(2, 5, 2, 5)));
 
 		VerticalLayoutContainer v = new VerticalLayoutContainer();
-		v.setScrollMode(ScrollMode.AUTO);
+		//v.setScrollMode(ScrollMode.AUTO); Set in GXT 3.0.1
 		v.add(new FieldLabel(comboValueColumn, "Value Column"),
 				new VerticalLayoutData(1, -1, new Margins(1)));
 
@@ -263,11 +263,13 @@ public class DenormalizePanel extends FramedPanel implements
 		storeComboAttributeColumn.commitChanges();
 		comboAttributeColumnLabel.setVisible(true);
 		denormalizeButton.disable();
+		forceLayout();
 
 	}
 
 	protected void updateComboAttributeColumn(ColumnData columnData) {
 		denormalizeButton.enable();
+		forceLayout();
 	}
 
 	protected void resetComboStatus() {
@@ -276,6 +278,7 @@ public class DenormalizePanel extends FramedPanel implements
 		storeComboAttributeColumn.commitChanges();
 		comboAttributeColumnLabel.setVisible(false);
 		denormalizeButton.disable();
+		forceLayout();
 	}
 
 	protected void loadData(ListLoadConfig loadConfig,
@@ -405,10 +408,10 @@ public class DenormalizePanel extends FramedPanel implements
 	}
 
 	@Override
-	public void operationComplete(TRId trId) {
+	public void operationComplete(OperationResult operationResult) {
 		ChangeTableWhy why = ChangeTableWhy.TABLEUPDATED;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.DENORMALIZE, trId, why);
+				ChangeTableRequestType.DENORMALIZE, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 	}
@@ -421,10 +424,10 @@ public class DenormalizePanel extends FramedPanel implements
 	}
 
 	@Override
-	public void operationStopped(TRId trId, String reason, String details) {
+	public void operationStopped(OperationResult operationResult, String reason, String details) {
 		ChangeTableWhy why = ChangeTableWhy.TABLECURATION;
 		ChangeTableRequestEvent changeTableRequestEvent = new ChangeTableRequestEvent(
-				ChangeTableRequestType.DENORMALIZE, trId, why);
+				ChangeTableRequestType.DENORMALIZE, operationResult.getTrId(), why);
 		eventBus.fireEvent(changeTableRequestEvent);
 		close();
 
